==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es_MX\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Hoja de Asistencia"
 ,"Hojas de Asistencia"

]
, "Account"
: "Cuenta"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Facturable"

, "Cleared in"
: "Autorizado el"

, "Invoice"
: ""

, "Cleared"
: "Autorizado"

, "Date"
: "Fecha"

, "Start time"
: "Hora de inicio"

, "End time"
: ""

, "Duration"
: "Duración"

, "Description"
: "Descripción"

, "Type"
: ""

, "Time Account closed"
: "Cuenta de Trabajo cerrada"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: ""

, "Title"
: "Título"

, "Number"
: "Número"

, "Price"
: ""

, "Status"
: "Estado"

, "Billed"
: "Facturado"

, "Cleared at"
: ""

, "Booking deadline"
: "Plazo de Reserva"

, "Responsible"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Cuenta de Trabajo"
 ,"Cuentas de Trabajo"

]
, "Time Account - Status"
: "Cuenta de Trabajo - Estado"

, "closed"
: "cerrado"

, "open"
: "abierto"

, "Not a valid time"
: "No es una hora válida"

, "Time Account - Billed"
: ""

, "not yet billed"
: "sin facturar aún"

, "to bill"
: "por facturar"

, "billed"
: "facturado"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Liquidado En"

, "Select Time Account..."
: "Seleccionar Cuenta de Trabajo..."

, "Start"
: "Comenzar"

, "not set"
: "no establecido"

, "End"
: ""

, "Enter description..."
: "Ingresar descripción..."

, "Need for Clarification"
: ""

, "Failed"
: "Falló"

, "Could not save {0}."
: "No se pudo grabar {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Fecha limite de reservación para esta Cuenta de Trabajo  a sido excedida."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Reservar Propia"

, "The grant to add Timesheets to this Timeaccount"
: "El permiso para agregar Hojas de Asistencia a esta Cuenta de Trabajo"

, "View All"
: "Ver Todos"

, "The grant to view Timesheets of other users"
: "El permiso para visualizar Hojas de Asistencia de otros usuarios"

, "Book All"
: "Reservar Todas"

, "The grant to add Timesheets for other users"
: "El permiso para agregar Hojas de Asistencia a otros usuarios"

, "Manage Clearing"
: "Administrar Autorizaciones"

, "The grant to manage clearing of Timesheets"
: "El permiso para administrar Autorizaciones de Hojas de Asistencia"

, "without contract"
: ""

, "without responsible"
: ""

, "timeframe"
: "periodo"

, "summary"
: "resumen"

, "Total Timesheets"
: "Total de Hojas de Asistencia"

, "Billable Timesheets"
: "Hojas de Asistencia Facturables"

, "Total Time"
: "Tiempo Total"

, "Time of Billable Timesheets"
: "Tiempo de Hojas de Asistencia Facturables"

, "Detail"
: "Detalle"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exportar Hojas de Asistencia"

, "Export as ODS"
: "Exportar como ODS"

, "Export as CSV"
: "Exportar como CVS"

, "Export as ..."
: "Exportar como..."

, "Add New Timeaccount"
: ""

, "Unit"
: "Unidad"

, "Unit Price"
: "Precio por Unidad"

, "Budget"
: "Presupuesto"

, "Timesheets are billable"
: "Hojas de Asistencia son facturables"

, "Access"
: "Acceso"

, "Permissions"
: "Permisos"

, "Show closed"
: "Mostrar cerrada"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Configuración de Exportación ODS de Hojas de Asistencia"

, "Use this configuration for the timesheet ODS export."
: "Utiliza esta configuración para exportación ODS de Hojas de Asistencia"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "predefinido"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "ninguno"

, "last week"
: "semana pasada"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Administrar Cuentas de Trabajo"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Agregar, editar y eliminar Cuentas de Trabajo (incluye toda asignación de Hojas de Asistencia)"

, "Add timeaccounts"
: "Agregar Cuentas de Trabajo"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: "Mis Hojas de Asistencia hoy"

, "My Timesheets this week"
: "Mis Hojas de Asistencia esta semana"

, "My Timesheets last week"
: "Mis Hojas de Asistencia semana pasada"

, "My Timesheets this month"
: "Mis Hojas de Asistencia este mes"

, "My Timesheets last month"
: "Mis Hojas de Asistencia mes pasado"

, "Timeaccounts to bill"
: "Cuentas de Trabajo por Facturar"

, "Timeaccounts not yet billed"
: "Cuentas de Trabajo aún no facturadas"

, "Timeaccounts already billed"
: "Cuentas de Trabajo Facturadas"

, "Timetracker"
: "Rastreador de Tiempo"

, "Timesheet"
: "Hoja de Asistencia"

, "Timeaccount"
: ""

, "Time Account"
: "Cuenta de Trabajo"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nLanguage: es_MX\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "periodo"

, "summary"
: "resumen"

, "Total Timesheets"
: "Total de Hojas de Asistencia"

, "Billable Timesheets"
: "Hojas de Asistencia Facturables"

, "Total Time"
: "Tiempo Total"

, "Time of Billable Timesheets"
: "Tiempo de Hojas de Asistencia Facturables"

, "Description"
: "Descripción"

, "Detail"
: "Detalle"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Exportar Hojas de Asistencia"

, "Export as ODS"
: "Exportar como ODS"

, "Export as CSV"
: "Exportar como CVS"

, "Export as ..."
: "Exportar como..."

, "Timesheet, Timesheets"
: [
  "Hoja de Asistencia"
 ,"Hojas de Asistencia"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Falló"

, "Could not save {0}."
: "No se pudo grabar {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Fecha limite de reservación para esta Cuenta de Trabajo  a sido excedida."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Unidad"

, "Unit Price"
: "Precio por Unidad"

, "Factor"
: ""

, "Budget"
: "Presupuesto"

, "Status"
: "Estado"

, "closed"
: "cerrado"

, "open"
: "abierto"

, "Cleared In"
: "Liquidado En"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Hojas de Asistencia son facturables"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Cuenta de Trabajo"
 ,"Cuentas de Trabajo"

]
, "Number"
: "Número"

, "Title"
: "Título"

, "Access"
: "Acceso"

, "Permissions"
: "Permisos"

, "Time Account - Billed"
: ""

, "not yet billed"
: "sin facturar aún"

, "to bill"
: "por facturar"

, "billed"
: "facturado"

, "Time Account - Status"
: "Cuenta de Trabajo - Estado"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Reservar Propia"

, "The grant to add Timesheets to this Timeaccount"
: "El permiso para agregar Hojas de Asistencia a esta Cuenta de Trabajo"

, "View All"
: "Ver Todos"

, "The grant to view Timesheets of other users"
: "El permiso para visualizar Hojas de Asistencia de otros usuarios"

, "Book All"
: "Reservar Todas"

, "The grant to add Timesheets for other users"
: "El permiso para agregar Hojas de Asistencia a otros usuarios"

, "Manage Clearing"
: "Administrar Autorizaciones"

, "The grant to manage clearing of Timesheets"
: "El permiso para administrar Autorizaciones de Hojas de Asistencia"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Mostrar cerrada"

, "Timesheets ODS export configuration"
: "Configuración de Exportación ODS de Hojas de Asistencia"

, "Use this configuration for the timesheet ODS export."
: "Utiliza esta configuración para exportación ODS de Hojas de Asistencia"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "predefinido"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "ninguno"

, "last week"
: "semana pasada"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Autorizado el"

, "Billed"
: "Facturado"

, "Booking deadline"
: "Plazo de Reserva"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Cuenta"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Facturable"

, "Cleared"
: "Autorizado"

, "Date"
: "Fecha"

, "Start time"
: "Hora de inicio"

, "End time"
: ""

, "Duration"
: "Duración"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Cuenta de Trabajo cerrada"

, "Timetracker"
: "Rastreador de Tiempo"

, "Timeaccounts to bill"
: "Cuentas de Trabajo por Facturar"

, "Timeaccounts not yet billed"
: "Cuentas de Trabajo aún no facturadas"

, "Timeaccounts already billed"
: "Cuentas de Trabajo Facturadas"

, "My Timesheets today"
: "Mis Hojas de Asistencia hoy"

, "My Timesheets this week"
: "Mis Hojas de Asistencia esta semana"

, "My Timesheets last week"
: "Mis Hojas de Asistencia semana pasada"

, "My Timesheets this month"
: "Mis Hojas de Asistencia este mes"

, "My Timesheets last month"
: "Mis Hojas de Asistencia mes pasado"

, "Manage timeaccounts"
: "Administrar Cuentas de Trabajo"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Agregar, editar y eliminar Cuentas de Trabajo (incluye toda asignación de Hojas de Asistencia)"

, "Add timeaccounts"
: "Agregar Cuentas de Trabajo"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Hoja de Asistencia"

, "Timeaccount"
: ""

, "Time Account"
: "Cuenta de Trabajo"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
